import React, { Key, ReactNode } from 'react';
import { SelectProps as AntSelectProps } from 'antd';
import { ColumnsType } from 'antd/es/table';
import { BaseOptionType } from 'antd/es/select';
/** 自定义表格的主要属性 */
export interface FieldNames {
    value: string;
    label: string;
    items?: string;
}
/** 分页属性 */
export interface PaginationProps {
    pageIndex: number;
    pageSize: number;
}
/** 分页数据change事件 */
export type PaginationChangeEvent = (page: number, pageSize: number) => void;
/** 下拉Popup左边区域渲染函数 */
export type TableSelectPopupParentRender = (spaceSize: number, tableHeight?: number) => React.ReactNode;
export interface BitzTableSelectProps<T extends BaseOptionType> extends AntSelectProps<any[], BaseOptionType> {
    /** 表单回填数据 */
    value?: Key[];
    /** 表单回填Options */
    options?: T[];
    /**
     * 表格列配置
     * @注意 render函数不需要返回组件时不要使用<></>包裹，直接返回string/number，
     * 或者干脆不要写render，会导致内容无法选中复制
     */
    columns: ColumnsType<T>;
    /** 表格数据 */
    tableData: T[];
    /** 加载表格数据 */
    loading: boolean;
    /** 加载失败 */
    loadingFailed: boolean;
    /** 重新加载 */
    loadAgain: () => void;
    /** 表格总数据条数 */
    total: number;
    /** 分页属性 */
    page: PaginationProps;
    /** 分页切换 */
    onPageChange: PaginationChangeEvent;
    /** 表格搜索input元素 */
    searchInput: ReactNode;
    /** 常用标签 */
    showToolTagSelect?: boolean;
    /** 常用标签options */
    toolTags?: AntSelectProps['options'];
    /** 常用标签change的值 */
    onToolTagChange?: AntSelectProps['onChange'];
    /** 左右布局 */
    lrLayout?: boolean;
    /** 下拉Popup左边区域渲染函数 */
    parentRender?: TableSelectPopupParentRender;
    /** 自定义表格的主要属性 */
    fieldNames: FieldNames;
    /** 下拉框 placeholder */
    placeholder?: string;
    /** 向父/组件传递数据的事件 */
    onChange?: (value: Key[]) => void;
}
/** 下拉表格组件 */
declare function BitzTableSelect<T extends BaseOptionType>({ columns, tableData, loading, loadingFailed, loadAgain, total, page, onPageChange, onSearch, showToolTagSelect, placeholder, fieldNames, ...rest }: BitzTableSelectProps<T>): import("react/jsx-runtime").JSX.Element;
export default BitzTableSelect;
